from django.db import models

# class Manager(models.Manager):
#
#     def get_queryset(self):
#         return super(Manager, self).get_queryset().filter(valid=True)
#
# class Model(models.Model):
#     valid = models.BooleanField(verbose_name='有效', default=True)
#     models = Manager()
#
#     class Meta:
#         abstract = False

